package
Version:
v0.0.0-...-1e16040
Opens a new window with list of versions in this module.
Published: Jul 24, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CallsLog struct {
CallTimestamp time.Time `json:"callTimestamp"`
ResponseTimeMs int64 `json:"responseTimeMs"`
Status string `json:"status"`
}
type Currency struct {
Id int `json:"id"`
Currency string `json:"currency"`
Value float64 `json:"value"`
Timestamp time.Time `json:"timestamp"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.